@@ -1,8 +1,9 @@
 create_binomial_baseline_evaluations <- function(test_data,
                                                  dependent_col,
-                                                 reps=100,
+                                                 reps = 100,
                                                  positive = 2,
                                                  cutoff = 0.5,
+                                                 na.rm = TRUE,
                                                  parallel_ = FALSE){
 
   # Check positive
@@ -16,7 +17,7 @@ create_binomial_baseline_evaluations <- function(test_data,
     stop("'positive' must be either a whole number or character.")
   }
   if (arg_is_wholenumber_(positive) && positive %ni% c(1,2)){
-    stop("When 'positive' is numeric, it must be either 0 or 1.")
+    stop("When 'positive' is numeric, it must be either 1 or 2.")
   }
 
   # Check cutoff
@@ -47,6 +48,11 @@ create_binomial_baseline_evaluations <- function(test_data,
     }
   }
 
+  # Check na.rm
+  if(!is_logical_scalar_not_na(na.rm)){
+    stop("'na.rm' must be logical scalar (TRUE/FALSE).")
+  }
+
   # Add fold info columns
   test_data[["rel_fold"]] <- 1
   test_data[["abs_fold"]] <- 1
@@ -65,7 +71,8 @@ create_binomial_baseline_evaluations <- function(test_data,
     basics_update_model_specifics()
 
   # Sample random probabilities
-  random_probabilities <- split(runif(n_targets*reps), f = factor(rep(1:reps, each=n_targets)))
+  random_probabilities <- split(runif(n_targets*reps),
+                                f = factor(rep(1:reps, each = n_targets)))
 
   # Create all 0 and all 1 probabilities
   all_0_probabilities <- rep(0.000001, n_targets)
@@ -80,15 +87,19 @@ create_binomial_baseline_evaluations <- function(test_data,
     # This will be changed to evaluation repetition later on
     test_data[["fold_column"]] <- evaluation
 
-    evaluate(test_data,
-             type = "binomial",
-             predictions_col = "prediction",
-             targets_col = dependent_col,
-             fold_info_cols = list(rel_fold = "rel_fold",
-                                   abs_fold = "abs_fold",
-                                   fold_column = "fold_column"),
-             # models=NULL,
-             model_specifics = model_specifics)
+    internal_evaluate(
+      test_data,
+      type = "binomial",
+      predictions_col = "prediction",
+      targets_col = dependent_col,
+      fold_info_cols = list(
+        rel_fold = "rel_fold",
+        abs_fold = "abs_fold",
+        fold_column = "fold_column"
+      ),
+      # models=NULL,
+      model_specifics = model_specifics
+    )
   }) %>% dplyr::bind_rows() %>% # Works with nested tibbles (ldply doesn't seem to)
     dplyr::mutate(
       Family = "binomial",
@@ -97,39 +108,8 @@ create_binomial_baseline_evaluations <- function(test_data,
 
   # TODO Rename Fold Column to Repetition or similar in evaluations$Predictions
 
-  metrics_cols <- select_metrics(evaluations_random, include_definitions = FALSE)
-
-  # Get rows with INFs
-  metrics_cols_with_infs <- metrics_cols[is.infinite(rowSums(metrics_cols)),]
-
-  # Replace infs with NA
-  if(nrow(metrics_cols_with_infs) > 0){
-    metrics_cols <- do.call(data.frame,c(lapply(metrics_cols, function(x) replace(x, is.infinite(x), NA)),
-                                         check.names=FALSE,fix.empty.names = FALSE, stringsAsFactors=FALSE))
-  }
-
-  # This may be better solveable with pivot_* from tidyr, when it is on CRAN
-  # This isn't exactly pretty.
-  summarized_metrics <- dplyr::bind_rows(
-    metrics_cols %>% dplyr::summarize_all(.funs = list(~mean(., na.rm = TRUE))) %>% dplyr::mutate(f = "Mean"),
-    metrics_cols %>% dplyr::summarize_all(.funs = list(~median(., na.rm = TRUE))) %>% dplyr::mutate(f = "Median"),
-    metrics_cols %>% dplyr::summarize_all(.funs = list(~sd(., na.rm = TRUE))) %>% dplyr::mutate(f = "SD"),
-    metrics_cols %>% dplyr::summarize_all(.funs = list(~IQR(., na.rm = TRUE))) %>% dplyr::mutate(f = "IQR"),
-    metrics_cols %>% dplyr::summarize_all(.funs = list(~max(., na.rm = TRUE))) %>% dplyr::mutate(f = "Max"),
-    metrics_cols %>% dplyr::summarize_all(.funs = list(~min(., na.rm = TRUE))) %>% dplyr::mutate(f = "Min"),
-    metrics_cols %>% dplyr::summarize_all(.funs = list(~sum(is.na(.)))) %>% dplyr::mutate(f = "NAs"),
-    metrics_cols_with_infs %>% dplyr::summarize_all(.funs = list(~sum(is.infinite(.)))) %>% dplyr::mutate(f = "INFs")
-  ) %>%
-    dplyr::select(.data$f, dplyr::everything()) %>%
-    dplyr::rename(Measure = .data$f)
-
-  # Remove the INFs from the NAs count
-  if(nrow(metrics_cols_with_infs) > 0){
-    NAs_row_number <- which(summarized_metrics$Measure == "NAs")
-    INFs_row_number <- which(summarized_metrics$Measure == "INFs")
-    summarized_metrics[NAs_row_number,-1] <- summarized_metrics[NAs_row_number,-1] - summarized_metrics[INFs_row_number,-1]
-  }
-
+  metric_cols <- select_metrics(evaluations_random, include_definitions = FALSE)
+  summarized_metrics <- summarize_metric_cols(metric_cols, na.rm = na.rm)
 
   # Evaluate all 0s
 
@@ -138,19 +118,27 @@ create_binomial_baseline_evaluations <- function(test_data,
   # This will be changed to evaluation repetition later on
   test_data[["fold_column"]] <- reps + 1
 
-  evaluations_all_0 <- evaluate(test_data,
-                                type = "binomial",
-                                predictions_col = "prediction",
-                                targets_col = dependent_col,
-                                fold_info_cols = list(rel_fold = "rel_fold",
-                                                      abs_fold = "abs_fold",
-                                                      fold_column = "fold_column"),
-                                # models = NULL,
-                                model_specifics = model_specifics) %>%
+  evaluations_all_0 <- internal_evaluate(
+    test_data,
+    type = "binomial",
+    predictions_col = "prediction",
+    targets_col = dependent_col,
+    fold_info_cols = list(
+      rel_fold = "rel_fold",
+      abs_fold = "abs_fold",
+      fold_column = "fold_column"
+    ),
+    # models = NULL,
+    model_specifics = model_specifics
+  ) %>%
     dplyr::mutate(Family = "binomial",
                   Dependent = dependent_col) %>%
     select_metrics(include_definitions = FALSE) %>%
-    dplyr::mutate( Measure = "All_0")
+    dplyr::mutate(Measure = paste0("All_",
+                                  ifelse(
+                                    is.character(test_data[[dependent_col]]),
+                                    sort(unique(test_data[[dependent_col]]))[[1]],
+                                    0)))
 
   # Evaluate all 1s
 
@@ -159,19 +147,26 @@ create_binomial_baseline_evaluations <- function(test_data,
   # This will be changed to evaluation repetition later on
   test_data[["fold_column"]] <- reps + 2
 
-  evaluations_all_1 <- evaluate(test_data,
-                                type = "binomial",
-                                predictions_col = "prediction",
-                                targets_col = dependent_col,
-                                fold_info_cols = list(rel_fold = "rel_fold",
-                                                      abs_fold = "abs_fold",
-                                                      fold_column = "fold_column"),
-                                # models=NULL,
-                                model_specifics = model_specifics) %>%
+  evaluations_all_1 <- internal_evaluate(
+    test_data,
+    type = "binomial",
+    predictions_col = "prediction",
+    targets_col = dependent_col,
+    fold_info_cols = list(
+      rel_fold = "rel_fold",
+      abs_fold = "abs_fold",
+      fold_column = "fold_column"
+    ),
+    # models=NULL,
+    model_specifics = model_specifics) %>%
     dplyr::mutate(Family = "binomial",
                   Dependent = dependent_col) %>%
     select_metrics(include_definitions = FALSE) %>%
-    dplyr::mutate( Measure = "All_1")
+    dplyr::mutate( Measure = paste0("All_",
+                                    ifelse(
+                                      is.character(test_data[[dependent_col]]),
+                                      sort(unique(test_data[[dependent_col]]))[[2]],
+                                      1)))
 
   # Collect the summarized metrics
 
@@ -184,3 +179,53 @@ create_binomial_baseline_evaluations <- function(test_data,
   return(list("summarized_metrics" = overall_evaluations,
               "random_evaluations" = evaluations_random))
 }
+
+
+replace_inf_with_na <- function(metric_cols){
+  # Get rows with INFs
+  metric_cols_with_infs <- metric_cols[is.infinite(rowSums(metric_cols)),]
+
+  # Replace infs with NA
+  if(nrow(metric_cols_with_infs) > 0){
+    metric_cols <- do.call(data.frame,c(lapply(metric_cols, function(x) replace(x, is.infinite(x), NA)),
+                                         check.names=FALSE,fix.empty.names = FALSE, stringsAsFactors=FALSE))
+  }
+
+  list("metric_cols" = metric_cols,
+       "metric_cols_with_infs" = metric_cols_with_infs)
+}
+
+summarize_metric_cols <- function(metric_cols, na.rm = TRUE){
+
+  # Start by replacing INF with NA
+  # We keep the infs as well, as we wish to distinguish between them in the summary
+  inf_replacement <- replace_inf_with_na(metric_cols)
+  metric_cols <- inf_replacement[["metric_cols"]]
+  metric_cols_with_infs <- inf_replacement[["metric_cols_with_infs"]]
+
+  # Summarize the metrics with a range of functions
+  # Note: This may be better solveable with pivot_* from tidyr, when it is on CRAN
+  # This isn't exactly pretty.
+
+  summarized_metrics <- dplyr::bind_rows(
+    metric_cols %>% dplyr::summarize_all(.funs = list(~mean(., na.rm = na.rm))) %>% dplyr::mutate(f = "Mean"),
+    metric_cols %>% dplyr::summarize_all(.funs = list(~median(., na.rm = na.rm))) %>% dplyr::mutate(f = "Median"),
+    metric_cols %>% dplyr::summarize_all(.funs = list(~sd(., na.rm = na.rm))) %>% dplyr::mutate(f = "SD"),
+    metric_cols %>% dplyr::summarize_all(.funs = list(~IQR(., na.rm = na.rm))) %>% dplyr::mutate(f = "IQR"),
+    metric_cols %>% dplyr::summarize_all(.funs = list(~max(., na.rm = na.rm))) %>% dplyr::mutate(f = "Max"),
+    metric_cols %>% dplyr::summarize_all(.funs = list(~min(., na.rm = na.rm))) %>% dplyr::mutate(f = "Min"),
+    metric_cols %>% dplyr::summarize_all(.funs = list(~sum(is.na(.)))) %>% dplyr::mutate(f = "NAs"),
+    metric_cols_with_infs %>% dplyr::summarize_all(.funs = list(~sum(is.infinite(.)))) %>% dplyr::mutate(f = "INFs")
+  ) %>%
+    dplyr::select(.data$f, dplyr::everything()) %>%
+    dplyr::rename(Measure = .data$f)
+
+  # Remove the INFs from the NAs count
+  if(nrow(metric_cols_with_infs) > 0){
+    NAs_row_number <- which(summarized_metrics$Measure == "NAs")
+    INFs_row_number <- which(summarized_metrics$Measure == "INFs")
+    summarized_metrics[NAs_row_number,-1] <- summarized_metrics[NAs_row_number,-1] - summarized_metrics[INFs_row_number,-1]
+  }
+
+  summarized_metrics
+}
