@@ -405,7 +405,7 @@ test_that("binomial models work with repeated cross_validate()",{
                                                      "Kappa","MCC","Detection Rate","Detection Prevalence",
                                                      "Prevalence"))
   expect_equal(colnames(CVbinomlist$ROC[[1]]), c("Fold Column","Sensitivities","Specificities"))
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_0","Pos_1","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_0","Pos_1","N"))
   expect_equal(nrow(CVbinomlist$Predictions[[1]]),60)
   expect_equal(nrow(CVbinomlist$ROC[[1]]),60)
   expect_equal(colnames(CVbinomlist$Coefficients[[1]]),
@@ -452,7 +452,7 @@ test_that("binomial models work with repeated cross_validate()",{
 
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$`Fold Column`, rep(c(".folds_1",".folds_2"), each=4))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$Prediction, as.character(c(0,1,0,1,0,1,0,1)))
-  expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$Reference, as.character(c(0,0,1,1,0,0,1,1)))
+  expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$Target, as.character(c(0,0,1,1,0,0,1,1)))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$Pos_0, rep(c("TP","FN","FP","TN"),2))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$Pos_1, rep(c("TN","FP","FN","TP"),2))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(7,5,2,16,7,5,3,15))
@@ -491,7 +491,7 @@ test_that("binomial models work with positive as.character in cross_validate()",
                                 REML = FALSE, model_verbose=FALSE,
                                 positive=1)
 
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_B","Pos_E","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_B","Pos_E","N"))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(16,2,5,7,15,3,5,7))
   expect_equal(CVbinomlist$F1, c(0.8049933, 0.5384615), tolerance=1e-3)
 
@@ -499,7 +499,7 @@ test_that("binomial models work with positive as.character in cross_validate()",
                                 fold_cols = c('.folds_1','.folds_2'), family='binomial',
                                 REML = FALSE, model_verbose=FALSE, positive="E")
 
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_B","Pos_E","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_B","Pos_E","N"))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(16,2,5,7,15,3,5,7))
   expect_equal(CVbinomlist$F1, c(0.6515152, NA), tolerance=1e-3)
 
@@ -507,7 +507,7 @@ test_that("binomial models work with positive as.character in cross_validate()",
                                 fold_cols = c('.folds_1','.folds_2'), family='binomial',
                                 REML = FALSE, model_verbose=FALSE, positive="B")
 
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_B","Pos_E","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_B","Pos_E","N"))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(16,2,5,7,15,3,5,7))
   expect_equal(CVbinomlist$F1, c(0.8049933, 0.5384615), tolerance=1e-3)
 
@@ -515,7 +515,7 @@ test_that("binomial models work with positive as.character in cross_validate()",
                                 fold_cols = c('.folds_1','.folds_2'), family='binomial',
                                 REML = FALSE, model_verbose=FALSE, positive=1)
 
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_B","Pos_E","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_B","Pos_E","N"))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(16,2,5,7,15,3,5,7))
   expect_equal(CVbinomlist$F1, c(0.8049933, 0.5384615), tolerance=1e-3)
 
@@ -523,7 +523,7 @@ test_that("binomial models work with positive as.character in cross_validate()",
                                 fold_cols = c('.folds_1','.folds_2'), family='binomial',
                                 REML = FALSE, model_verbose=FALSE, positive=2)
 
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_B","Pos_E","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_B","Pos_E","N"))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(16,2,5,7,15,3,5,7))
   expect_equal(CVbinomlist$F1, c(0.6515152, NA), tolerance=1e-3)
 
@@ -546,7 +546,7 @@ test_that("binomial models work with positive as.character in cross_validate()",
                                 REML = FALSE, model_verbose=FALSE,
                                 positive=1)
 
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_B","Pos_E","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_B","Pos_E","N"))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(7,5,2,16,7,5,3,15))
   expect_equal(CVbinomlist$F1, c(0.6515152, NA), tolerance=1e-3)
 
@@ -554,7 +554,7 @@ test_that("binomial models work with positive as.character in cross_validate()",
                                 fold_cols = c('.folds_1','.folds_2'), family='binomial',
                                 REML = FALSE, model_verbose=FALSE, positive="E")
 
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_B","Pos_E","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_B","Pos_E","N"))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(7,5,2,16,7,5,3,15))
   expect_equal(CVbinomlist$F1, c(0.8049933,0.5384615), tolerance=1e-3)
 
@@ -562,7 +562,7 @@ test_that("binomial models work with positive as.character in cross_validate()",
                                 fold_cols = c('.folds_1','.folds_2'), family='binomial',
                                 REML = FALSE, model_verbose=FALSE, positive="B")
 
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_B","Pos_E","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_B","Pos_E","N"))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(7,5,2,16,7,5,3,15))
   expect_equal(CVbinomlist$F1, c(0.6515152, NA), tolerance=1e-3)
 
@@ -570,7 +570,7 @@ test_that("binomial models work with positive as.character in cross_validate()",
                                 fold_cols = c('.folds_1','.folds_2'), family='binomial',
                                 REML = FALSE, model_verbose=FALSE, positive=1)
 
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_B","Pos_E","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_B","Pos_E","N"))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(7,5,2,16,7,5,3,15))
   expect_equal(CVbinomlist$F1, c(0.6515152, NA), tolerance=1e-3)
 
@@ -578,7 +578,7 @@ test_that("binomial models work with positive as.character in cross_validate()",
                                 fold_cols = c('.folds_1','.folds_2'), family='binomial',
                                 REML = FALSE, model_verbose=FALSE, positive=2)
 
-  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Reference","Pos_B","Pos_E","N"))
+  expect_equal(colnames(CVbinomlist$`Confusion Matrix`[[1]]), c("Fold Column","Prediction","Target","Pos_B","Pos_E","N"))
   expect_equal(CVbinomlist$`Confusion Matrix`[[1]]$N, c(7,5,2,16,7,5,3,15))
   expect_equal(CVbinomlist$F1, c(0.8049933,0.5384615), tolerance=1e-3)
 
