@@ -1,11 +1,11 @@
 library(cvms)
 context("helpers")
 
-test_that("Helper count_named_nulls_in_list() works",{
+test_that("Helper count_nulls_in_list() works",{
 
   # skip_test_if_old_R_version()
 
-  expect_equal(count_named_nulls_in_list(list("cat"=NULL, "dog"=3, "hat"=NULL)), 2)
+  expect_equal(count_nulls_in_list(list("cat"=NULL, "dog"=3, "hat"=NULL)), 2)
 
 })
 
